# Adding and Editing Data in Fact Sheets
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/adding-and-editing-data-in-fact-sheets#introduction)
  * [Adding and Editing Data in a Fact Sheet](https://help.sap.com/docs/leanix/ea/adding-and-editing-data-in-fact-sheets#adding-and-editing-data-in-a-fact-sheet)
  * [Adding Relations](https://help.sap.com/docs/leanix/ea/adding-and-editing-data-in-fact-sheets#adding-relations)
  * [Adding Relations in Bulk Using Filters](https://help.sap.com/docs/leanix/ea/adding-and-editing-data-in-fact-sheets#adding-relations-in-bulk-using-filters)
  * [Editing Relations](https://help.sap.com/docs/leanix/ea/adding-and-editing-data-in-fact-sheets#editing-relations)
  * [Constraining Relations](https://help.sap.com/docs/leanix/ea/adding-and-editing-data-in-fact-sheets#constraining-relations)
  * [Leaving a Relation Empty](https://help.sap.com/docs/leanix/ea/adding-and-editing-data-in-fact-sheets#leaving-a-relation-empty)
  * [Deleting Relations](https://help.sap.com/docs/leanix/ea/adding-and-editing-data-in-fact-sheets#deleting-relations)


View all
Users with the appropriate permissions can add and edit data in fact sheets, while administrators can customize and manage these permissions. By switching to table view in the inventory, you can perform inline editing across multiple fact sheets, and using the import option, you can update multiple fact sheets in bulk.
